# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: endpoints/sdk_server_ready.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n endpoints/sdk_server_ready.proto\x12\tendpoints\"I\n\x15SDKServerReadyRequest\x12\x1c\n\x0fsdk_server_port\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x12\n\x10_sdk_server_port\"\x18\n\x16SDKServerReadyResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'endpoints.sdk_server_ready_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SDKSERVERREADYREQUEST._serialized_start=47
  _SDKSERVERREADYREQUEST._serialized_end=120
  _SDKSERVERREADYRESPONSE._serialized_start=122
  _SDKSERVERREADYRESPONSE._serialized_end=146
# @@protoc_insertion_point(module_scope)
